@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution
 #
-#  Copyright 2008-2019 Statnet Commons
+#  Copyright 2008-2020 Statnet Commons
 #######################################################################
 stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss, model.mon,
                             control, proposal.form, proposal.diss, eval.optpars,
@@ -29,7 +29,7 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
     control$SA.plot.progress <- FALSE # So that we don't print a warning every step.
   }
   
-  if(verbose) cat("Starting optimization with with coef_F_0 = (",theta.form0, ") and coef_D_0 = (",theta.diss0,")\n" )
+  if(verbose) message("Starting optimization with with coef_F_0 = ( ", paste(theta.form0, collapse = " "), " ) and coef_D_0 = ( ", paste(theta.diss0, collapse = " ")," )")
   ###### Define the optimization run function. ######
   
   do.optimization<-function(states, history, control){
@@ -38,20 +38,20 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
     oh.all <- history$oh.all
     jitters.all <- history$jitters.all
     
-    if(verbose) cat("Running stochastic optimization... ")
+    if(verbose) message("Running stochastic optimization... ", appendLF = FALSE)
     zs <- if(!is.null(ergm.getCluster(control))){
       requireNamespace('parallel')
       # Conveniently, the first argument of stergm.EGMME.SA.Phase2.C
       # is the state of the optimization, so giving clusterApply a
       # list of states will call it for each thread's state.
-      if(verbose) {cat("Calling stergm.EGMME.SA.Phase2.C:\n"); print(gc())}
+      if(verbose) {message("Calling stergm.EGMME.SA.Phase2.C:"); message_print(gc())}
       out <- parallel::clusterApply(ergm.getCluster(control), states, stergm.EGMME.SA.Phase2.C, model.form, model.diss, model.mon, proposal.form, proposal.diss, control, verbose=verbose)
-      if(verbose) print(gc())
+      if(verbose) message_print(gc())
       out
     }else{
       list(stergm.EGMME.SA.Phase2.C(states[[1]], model.form, model.diss, model.mon, proposal.form, proposal.diss, control, verbose=verbose))
     }
-    if(verbose) cat("Finished. Extracting.\n")
+    if(verbose) message("Finished. Extracting.")
     for(i in seq_along(states)){
 
       # Extend the observation index and thread id vectors.
@@ -208,7 +208,7 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
                         simplify=FALSE
                         )
     
-    cat('========  Phase 1: Burn in, get initial gradient values, and find a configuration under which all targets vary. ========\n',sep="")
+    message('========  Phase 1: Burn in, get initial gradient values, and find a configuration under which all targets vary. ========')
     
     ###### Set up and run the burn-in. ######
 
@@ -218,19 +218,19 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
     control.phase1$time.burnin <- control$SA.burnin
     control.phase1$time.interval <- 1
     
-    cat("Burning in... ")
+    message("Burning in... ", appendLF = FALSE)
     
     zs <- if(!is.null(ergm.getCluster(control))){
       requireNamespace('parallel')
-      if(verbose) {cat("Calling stergm.getMCMCsample:\n"); print(gc())}
+      if(verbose) {message("Calling stergm.getMCMCsample:"); message_print(gc())}
       out <- parallel::clusterApply(ergm.getCluster(control), seq_along(states), function(i) stergm_MCMC_sample(states[[i]]$nw, model.form, model.diss, model.mon, proposal.form, proposal.diss, eta.form=states[[i]]$eta.form, eta.diss=states[[i]]$eta.diss, control=control.phase1, verbose=verbose))
-      if(verbose) print(gc())
+      if(verbose) message_print(gc())
       out
     }else{
       list(stergm_MCMC_sample(states[[1]]$nw, model.form, model.diss, model.mon, proposal.form, proposal.diss, eta.form=states[[1]]$eta.form, eta.diss=states[[1]]$eta.diss, control=control.phase1, verbose=verbose))
     }
     
-    cat("Done.\n")
+    message("Done.")
     
     # Update the state with burn-in results.
     for(i in seq_along(zs)){
@@ -262,15 +262,15 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
     control$SA.burnin <- control$SA.interval <- 10 # TODO: Kirk : check this
   
     if(verbose>1){
-      cat("New interval:",control$SA.interval ,"\n")
+      message("New interval: ", control$SA.interval)
     }  
     
     for(try in 1:control$SA.phase1.tries){
-      if(verbose) cat('======== Attempt ',try,' ========\n',sep="") else cat('Attempt',try,':\n')
+      if(verbose) message('======== Attempt ', try, ' ========') else message('Attempt ', try,' :')
       for(run in 1:control$SA.phase1.minruns){
         tmp <- if(control$SA.restart.on.err) try(do.optimization(states, history, control), silent=!verbose) else do.optimization(states, history, control)
         if(inherits(tmp, "try-error") || all(apply(tmp$history$oh.last[,-(1:p),drop=FALSE],2,var)<sqrt(.Machine$double.eps))){
-          cat("Something went very wrong. Restarting with smaller gain.\n")
+          message("Something went very wrong. Restarting with smaller gain.")
           control$SA.init.gain <- control$SA.init.gain * control$SA.gain.decay
           do.restart <- TRUE
           break
@@ -286,7 +286,7 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
       control$gain <- control$SA.init.gain
       out <- if(control$SA.restart.on.err) try(eval.optpars(states, history, control, TRUE,restart>1,FALSE), silent=!verbose) else eval.optpars(states, history, control, TRUE,restart>1,FALSE)
       if(inherits(out, "try-error") || all(apply(history$oh.last[,-(1:p),drop=FALSE],2,var)<sqrt(.Machine$double.eps))){
-        cat("Something went very wrong. Restarting with smaller gain.\n")
+        message("Something went very wrong. Restarting with smaller gain.")
         control$SA.init.gain <- control$SA.init.gain * control$SA.gain.decay
         do.restart <- TRUE
         break
@@ -294,7 +294,7 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
       control <- out$control
 
       if(all(!out$ineffectual.pars) && all(!out$bad.fits)){
-        cat("All parameters have some effect and all statistics are moving. Proceeding to Phase 2.\n")
+        message("All parameters have some effect and all statistics are moving. Proceeding to Phase 2.")
         break
       }
       if(try==control$SA.phase1.tries) stop("The optimizer was unable to find a reasonable configuration: one or more statistics are still stuck after multiple tries, and one or more parameters do not appear to have any robust effect.")
@@ -303,10 +303,10 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
     
     ###### Main optimization run. ######
     
-    cat('========  Phase 2: Find and refine the estimate. ========\n',sep="")
+    message('========  Phase 2: Find and refine the estimate. ========')
     
     for(subphase in 1:control$SA.phase2.levels.max){
-      if(verbose) cat('======== Subphase ',subphase,' ========\n',sep="") else cat('Subphase 2.',subphase,' ',sep="")
+      if(verbose) message('======== Subphase ', subphase, ' ========') else message('Subphase 2.', subphase, ' ', appendLF=FALSE)
       
       control$gain <- control$SA.init.gain*control$SA.gain.decay^(subphase-1)
       stepdown.count <- control$SA.stepdown.ct
@@ -314,7 +314,7 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
       for(regain in 1:control$SA.phase2.repeats){
         tmp <- if(control$SA.restart.on.err) try(do.optimization(states, history, control), silent=!verbose) else do.optimization(states, history, control)
         if(inherits(tmp, "try-error") || all(apply(tmp$history$oh.last[,-(1:p),drop=FALSE],2,var)<sqrt(.Machine$double.eps))){
-          cat("Something went very wrong. Restarting with smaller gain.\n")
+          message("Something went very wrong. Restarting with smaller gain.")
           control$SA.init.gain <- control$SA.init.gain * control$SA.gain.decay
           do.restart <- TRUE
           break
@@ -325,17 +325,17 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
         }
         
         if(verbose){
-          cat("New parameters:\n")
-          cat("Formation:\n")
-          for(state in states) print(state$eta.form)
-          cat("Dissolution:\n")
-          for(state in states) print(state$eta.diss)
+          message("New parameters:")
+          message("Formation:")
+          for(state in states) message_print(state$eta.form)
+          message("Dissolution:")
+          for(state in states) message_print(state$eta.diss)
         }
 
         ## Get updated gain and other values
         out <- if(control$SA.restart.on.err) try(eval.optpars(states, history, control, FALSE,TRUE,TRUE), silent=!verbose) else eval.optpars(states, history, control, FALSE,TRUE,TRUE)
         if(inherits(out, "try-error") || all(apply(history$oh.last[,-(1:p),drop=FALSE],2,var)<sqrt(.Machine$double.eps))){
-          cat("Something went very wrong. Restarting with smaller gain.\n")
+          message("Something went very wrong. Restarting with smaller gain.")
           control$SA.init.gain <- control$SA.init.gain * control$SA.gain.decay
           do.restart <- TRUE
           break
@@ -370,7 +370,7 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
           if(est.2>0) p.val.2 <- 1-p.val.2 # If it's actually getting worse one-sided p-value is thus.
           
           if(verbose){
-            cat("Estimating equations = 0 p-value:",p.val.1,", trending:", p.val.2, ".\n")
+            message("Estimating equations = 0 p-value: ", p.val.1, " , trending: ", p.val.2, " .")
           }
 
           p.vals <- c(p.val.1,p.val.2)
@@ -383,23 +383,23 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
           if(fisher.pval(p.vals)>control$SA.stepdown.p){
             stepdown.count <- stepdown.count - 1
             if(stepdown.count<=0){
-              if(verbose) cat("Estimating equations do not significantly differ from 0 and neither they nor the parameters exhibit a significant trend. Reducing gain.\n")
-              else cat("\\")
+              if(verbose) message("Estimating equations do not significantly differ from 0 and neither they nor the parameters exhibit a significant trend. Reducing gain.")
+              else message("\\", appendLF = FALSE)
               stepdown.count <- control$SA.stepdown.ct
-              if(!verbose) cat("\n")
+              if(!verbose) message("")
               break
             }else{
-              if(verbose) cat("Estimating equations do not significantly differ from 0 and do not exhibit a significant trend. ",stepdown.count,"/",control$SA.stepdown.ct," to go.\n")
-              else cat("\\")
+              if(verbose) message("Estimating equations do not significantly differ from 0 and do not exhibit a significant trend.  ", stepdown.count, " / ", control$SA.stepdown.ct, "  to go.")
+              else message("\\", appendLF = FALSE)
             }
           }else{
             stepdown.count <- control$SA.stepdown.ct
-            if(verbose) cat("Estimating equations significantly differ from 0 or exhibit a significant trend. Resetting counter.\n")
-            else cat("/")
+            if(verbose) message("Estimating equations significantly differ from 0 or exhibit a significant trend. Resetting counter.")
+            else message("/", appendLF = FALSE)
           }
         }else{
-          if(verbose) cat("Problem testing estimating equations. Continuing with current gain.\n")
-          else cat("!/")
+          if(verbose) message("Problem testing estimating equations. Continuing with current gain.")
+          else message("!/", appendLF = FALSE)
 
         }
         if(do.restart) break
@@ -428,12 +428,12 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
       sandwich.se <- sqrt(diag(V.sandwich(out$w,out$G,out$v)))
 
       if(verbose){
-        cat("Approximate standard error of the estimate:\n")
-        print(sandwich.se)        
-        cat("Approximate standard error of window means:\n")
-        print(par.se)
-        cat("par. var. / (std. var. + par. var.):\n")
-        print(par.se^2/(sandwich.se^2+par.se^2))
+        message("Approximate standard error of the estimate:")
+        message_print(sandwich.se)        
+        message("Approximate standard error of window means:")
+        message_print(par.se)
+        message("par. var. / (std. var. + par. var.):")
+        message_print(par.se^2/(sandwich.se^2+par.se^2))
       }
       
       # Test 2:
@@ -455,18 +455,18 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
       chi2 <- mahalanobis(c(nlin.coef),0,ginv(nlin.vcov),inverted=TRUE)
 
       p.val.1 <- pchisq(chi2, length(nlin.coef), lower.tail=FALSE)
-      if(verbose) cat("Local nonlinearity p-value:",p.val.1,"\n")
+      if(verbose) message("Local nonlinearity p-value: ", p.val.1)
 
       if(subphase == control$SA.phase2.levels.max){
-        if(verbose) cat("Maximum number of gain levels exceeded. Stopping.")
+        if(verbose) message("Maximum number of gain levels exceeded. Stopping.", appendLF = FALSE)
       }else{
         if(all(par.se^2/(sandwich.se^2+par.se^2) > control$SA.phase2.max.mc.se)){
-          if(verbose) cat("EGMME does not appear to be estimated with sufficient prescision. Continuing.\n")
+          if(verbose) message("EGMME does not appear to be estimated with sufficient prescision. Continuing.")
           next
         }
         
         if(p.val.1 < control$SA.stop.p){
-          if(verbose) cat("There is evidence of local nonlinearity. Continuing.\n")
+          if(verbose) message("There is evidence of local nonlinearity. Continuing.")
           next
         }
       }
@@ -487,11 +487,11 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
       if(p.diss.free) eta.diss[!model.diss$etamap$offsettheta] <- eta.free[p.form.free+seq_len(p.diss.free)]
       
       if(verbose){
-        cat("Refining the estimate using the", control$SA.refine,"method. New estimate:\n")
-        cat("Formation:\n")
-        print(eta.form)
-        cat("Dissolution:\n")
-        print(eta.diss)
+        message("Refining the estimate using the ", control$SA.refine, " method. New estimate:")
+        message("Formation:")
+        message_print(eta.form)
+        message("Dissolution:")
+        message_print(eta.diss)
       }
       
       ## Sample to estimate standard error and test if we've actually arrived.
@@ -499,14 +499,14 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
       w <- out$w
       V.par<-matrix(NA,p,p)
       if(control$SA.se){
-        cat('========  Phase 3: Simulate from the fit and estimate standard errors. ========\n',sep="")
+        message('========  Phase 3: Simulate from the fit and estimate standard errors. ========')
         
-        if(verbose)cat("Evaluating target statistics at the estimate.\n")
+        if(verbose) message("Evaluating target statistics at the estimate.")
 
         # This is to avoid the latest sample "pushing out" everything else.
         control$SA.keep.min <- round(nrow(history$oh)/length(states))+control$SA.phase3.samplesize.runs*control$SA.runlength*control$SA.interval
         tmp <- do.dummy.run(states, history, control, control$SA.burnin, control$SA.phase3.samplesize.runs*control$SA.runlength*control$SA.interval, eta.form=eta.form, eta.diss=eta.diss)
-        if(verbose)cat("Finished.\n")
+        if(verbose) message("Finished.")
         states <- tmp$states
         history <- tmp$history
         rm(tmp); gc()
@@ -519,16 +519,16 @@ stergm.EGMME.SA <- function(theta.form0, theta.diss0, nw, model.form, model.diss
         ee <- sm.mon %*% ginv(V.stat) %*% G
         p.val.1 <- approx.hotelling.diff.test(ee)$p.value
 
-        if(verbose) cat("Estimating equation = 0 p-value:",p.val.1,"\n")
+        if(verbose) message("Estimating equation = 0 p-value: ", p.val.1)
 
         if(subphase == control$SA.phase2.levels.max){
-          if(verbose) cat("Maximum number of gain levels exceeded. Stopping.")
+          if(verbose) message("Maximum number of gain levels exceeded. Stopping.", appendLF=FALSE)
         }else{
           if(p.val.1 < control$SA.stop.p){
-            if(verbose) cat("Simulated values of estimating equations are not centered around 0. Continuing.\n")
+            if(verbose) message("Simulated values of estimating equations are not centered around 0. Continuing.")
             next
           }else{
-            if(verbose) cat("Simulated values of estimating equations are centered around 0. Stopping.\n")          
+            if(verbose) message("Simulated values of estimating equations are centered around 0. Stopping.")          
           }
         }
         
@@ -576,15 +576,18 @@ stergm.EGMME.SA.Phase2.C <- function(state, model.form, model.diss, model.mon,
   maxedges <- max(control$MCMC.init.maxedges, Clist.mon$nedges)
   maxchanges <- max(control$MCMC.init.maxchanges, Clist.mon$nedges)
 
-  eta.form <- ergm:::.deinf(state$eta.form)
-  eta.diss <- ergm:::.deinf(state$eta.diss)
+  eta.form <- deInf(state$eta.form)
+  eta.diss <- deInf(state$eta.diss)
+  
+  lasttoggle_flag <- as.integer(!is.null(NVL(Clist.form$lasttoggle,Clist.diss$lasttoggle,Clist.mon$lasttoggle)))
   
   repeat{
     z <- .C("MCMCDynSArun_wrapper",
             # Observed/starting network. 
             as.integer(Clist.form$tails), as.integer(Clist.form$heads),
             time = as.integer(min(Clist.form$time,Clist.diss$time,Clist.diss$time)),
-            lasttoggle = as.integer(NVL(Clist.form$lasttoggle,Clist.diss$lasttoggle,Clist.mon$lasttoggle,0)),  
+            lasttoggle_flag,
+            lasttoggle = as.integer(NVL(Clist.form$lasttoggle,Clist.diss$lasttoggle,Clist.mon$lasttoggle)),  
             as.integer(Clist.form$nedges),
             as.integer(Clist.form$n),
             as.integer(Clist.form$dir), as.integer(Clist.form$bipartite),
@@ -642,7 +645,7 @@ stergm.EGMME.SA.Phase2.C <- function(state, model.form, model.diss, model.mon,
 
   newnetwork<-as.network(pending_update_network(state$nw,z))
   newnetwork %n% "time" <- z$time
-  newnetwork %n% "lasttoggle" <- z$lasttoggle
+  newnetwork %n% "lasttoggle" <- if(lasttoggle_flag) z$lasttoggle else NULL
   
   list(nw.diff=z$nw.diff,
        newnetwork=newnetwork,
